@@ -16,7 +16,7 @@
 //
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#  include "config.h"
 #endif
 
 #include "WorkraveApplet.h"
@@ -39,7 +39,7 @@ struct _WorkraveAppletPrivate
   gboolean alive;
 };
 
-G_DEFINE_TYPE_WITH_PRIVATE (WorkraveApplet, workrave_applet, PANEL_TYPE_APPLET);
+G_DEFINE_TYPE_WITH_PRIVATE(WorkraveApplet, workrave_applet, PANEL_TYPE_APPLET);
 
 static void workrave_applet_fill(WorkraveApplet *applet);
 static void dbus_call_finish(GDBusProxy *proxy, GAsyncResult *res, gpointer user_data);
@@ -54,29 +54,26 @@ struct Menuitems
   char *dbuscmd;
 };
 
-static struct Menuitems menu_data[] =
-  {
-    { MENU_COMMAND_OPEN,                  TRUE,  TRUE,  "open",         NULL,         "OpenMain"          },
-    { MENU_COMMAND_PREFERENCES,           FALSE, FALSE, "preferences",  NULL,         "Preferences"       },
-    { MENU_COMMAND_EXERCISES,             FALSE, FALSE, "exercises",    NULL,         "Exercises"         },
-    { MENU_COMMAND_REST_BREAK,            FALSE, FALSE, "restbreak",    NULL,         "RestBreak"         },
-    { MENU_COMMAND_MODE_NORMAL,           FALSE, FALSE, "mode",         "normal",     NULL                },
-    { MENU_COMMAND_MODE_QUIET,            FALSE, FALSE, "mode",         "quiet",      NULL                },
-    { MENU_COMMAND_MODE_SUSPENDED,        FALSE, FALSE, "mode",         "suspended",  NULL                },
-    { MENU_COMMAND_NETWORK_CONNECT,       FALSE, FALSE, "join",         NULL,         "NetworkConnect"    },
-    { MENU_COMMAND_NETWORK_DISCONNECT,    FALSE, FALSE, "disconnect",   NULL,         "NetworkDisconnect" },
-    { MENU_COMMAND_NETWORK_LOG,           FALSE, FALSE, "showlog",      NULL,         "NetworkLog"        },
-    { MENU_COMMAND_NETWORK_RECONNECT,     FALSE, FALSE, "reconnect",    NULL,         "NetworkReconnect"  },
-    { MENU_COMMAND_STATISTICS,            FALSE, FALSE, "statistics",   NULL,         "Statistics"        },
-    { MENU_COMMAND_ABOUT,                 FALSE, TRUE,  "about",        NULL,         NULL                },
-    { MENU_COMMAND_MODE_READING,          FALSE, FALSE, "readingmode",  NULL,         "ReadingMode"       },
-    { MENU_COMMAND_QUIT,                  FALSE, FALSE, "quit",         NULL,         "Quit"              }
-  };
+static struct Menuitems menu_data[] = {{MENU_COMMAND_OPEN, TRUE, TRUE, "open", NULL, "OpenMain"},
+                                       {MENU_COMMAND_PREFERENCES, FALSE, FALSE, "preferences", NULL, "Preferences"},
+                                       {MENU_COMMAND_EXERCISES, FALSE, FALSE, "exercises", NULL, "Exercises"},
+                                       {MENU_COMMAND_REST_BREAK, FALSE, FALSE, "restbreak", NULL, "RestBreak"},
+                                       {MENU_COMMAND_MODE_NORMAL, FALSE, FALSE, "mode", "normal", NULL},
+                                       {MENU_COMMAND_MODE_QUIET, FALSE, FALSE, "mode", "quiet", NULL},
+                                       {MENU_COMMAND_MODE_SUSPENDED, FALSE, FALSE, "mode", "suspended", NULL},
+                                       {MENU_COMMAND_NETWORK_CONNECT, FALSE, FALSE, "join", NULL, "NetworkConnect"},
+                                       {MENU_COMMAND_NETWORK_DISCONNECT, FALSE, FALSE, "disconnect", NULL, "NetworkDisconnect"},
+                                       {MENU_COMMAND_NETWORK_LOG, FALSE, FALSE, "showlog", NULL, "NetworkLog"},
+                                       {MENU_COMMAND_NETWORK_RECONNECT, FALSE, FALSE, "reconnect", NULL, "NetworkReconnect"},
+                                       {MENU_COMMAND_STATISTICS, FALSE, FALSE, "statistics", NULL, "Statistics"},
+                                       {MENU_COMMAND_ABOUT, FALSE, TRUE, "about", NULL, NULL},
+                                       {MENU_COMMAND_MODE_READING, FALSE, FALSE, "readingmode", NULL, "ReadingMode"},
+                                       {MENU_COMMAND_QUIT, FALSE, FALSE, "quit", NULL, "Quit"}};
 
 int
 lookup_menu_index_by_id(enum MenuCommand id)
 {
-  for (int i = 0; i < sizeof(menu_data)/sizeof(struct Menuitems); i++)
+  for (int i = 0; i < sizeof(menu_data) / sizeof(struct Menuitems); i++)
     {
       if (menu_data[i].id == id)
         {
@@ -90,7 +87,7 @@ lookup_menu_index_by_id(enum MenuCommand id)
 int
 lookup_menu_index_by_action(const char *action)
 {
-  for (int i = 0; i < sizeof(menu_data)/sizeof(struct Menuitems); i++)
+  for (int i = 0; i < sizeof(menu_data) / sizeof(struct Menuitems); i++)
     {
       if (g_strcmp0(menu_data[i].action, action) == 0)
         {
@@ -101,7 +98,8 @@ lookup_menu_index_by_action(const char *action)
   return -1;
 }
 
-void on_alive_changed(gpointer instance, gboolean alive, gpointer user_data)
+void
+on_alive_changed(gpointer instance, gboolean alive, gpointer user_data)
 {
   WorkraveApplet *applet = WORKRAVE_APPLET(user_data);
 
@@ -109,7 +107,7 @@ void on_alive_changed(gpointer instance, gboolean alive, gpointer user_data)
 
   if (!alive)
     {
-      for (int i = 0; i < sizeof(menu_data)/sizeof(struct Menuitems); i++)
+      for (int i = 0; i < sizeof(menu_data) / sizeof(struct Menuitems); i++)
         {
           GAction *action = g_action_map_lookup_action(G_ACTION_MAP(applet->priv->action_group), menu_data[i].action);
           g_simple_action_set_enabled(G_SIMPLE_ACTION(action), menu_data[i].visible_when_not_running);
@@ -117,18 +115,19 @@ void on_alive_changed(gpointer instance, gboolean alive, gpointer user_data)
     }
 }
 
-void on_menu_changed(gpointer instance, GVariant *parameters, gpointer user_data)
+void
+on_menu_changed(gpointer instance, GVariant *parameters, gpointer user_data)
 {
   WorkraveApplet *applet = WORKRAVE_APPLET(user_data);
   GVariantIter *iter;
-  g_variant_get (parameters, "(a(sii))", &iter);
+  g_variant_get(parameters, "(a(sii))", &iter);
 
   char *text;
   int id;
   int flags;
 
-  gboolean visible[sizeof(menu_data)/sizeof(struct Menuitems)];
-  for (int i = 0; i < sizeof(menu_data)/sizeof(struct Menuitems); i++)
+  gboolean visible[sizeof(menu_data) / sizeof(struct Menuitems)];
+  for (int i = 0; i < sizeof(menu_data) / sizeof(struct Menuitems); i++)
     {
       visible[i] = menu_data[i].visible_when_not_running;
     }
@@ -143,8 +142,7 @@ void on_menu_changed(gpointer instance, GVariant *parameters, gpointer user_data
 
       GAction *action = g_action_map_lookup_action(G_ACTION_MAP(applet->priv->action_group), menu_data[index].action);
 
-      if (flags & MENU_ITEM_FLAG_SUBMENU_END ||
-          flags & MENU_ITEM_FLAG_SUBMENU_BEGIN)
+      if (flags & MENU_ITEM_FLAG_SUBMENU_END || flags & MENU_ITEM_FLAG_SUBMENU_BEGIN)
         {
           continue;
         }
@@ -167,16 +165,15 @@ void on_menu_changed(gpointer instance, GVariant *parameters, gpointer user_data
         }
     }
 
-  g_variant_iter_free (iter);
+  g_variant_iter_free(iter);
 
-  for (int i = 0; i < sizeof(menu_data)/sizeof(struct Menuitems); i++)
+  for (int i = 0; i < sizeof(menu_data) / sizeof(struct Menuitems); i++)
     {
       GAction *action = g_action_map_lookup_action(G_ACTION_MAP(applet->priv->action_group), menu_data[i].action);
       g_simple_action_set_enabled(G_SIMPLE_ACTION(action), visible[i]);
     }
 }
 
-
 static void
 dbus_call_finish(GDBusProxy *proxy, GAsyncResult *res, gpointer user_data)
 {
@@ -205,20 +202,30 @@ on_menu_about(GSimpleAction *action, GVariant *parameter, gpointer user_data)
   gtk_container_set_border_width(GTK_CONTAINER(about), 5);
 
   gtk_show_about_dialog(NULL,
-                        "name", "Workrave",
+                        "name",
+                        "Workrave",
 #ifdef GIT_VERSION
-                        "version", PACKAGE_VERSION "\n(" GIT_VERSION ")",
+                        "version",
+                        PACKAGE_VERSION "\n(" GIT_VERSION ")",
 #else
-                        "version", PACKAGE_VERSION,
+                        "version",
+                        PACKAGE_VERSION,
 #endif
-                        "copyright", workrave_copyright,
-                        "website", "http://www.workrave.org",
-                        "website_label", "www.workrave.org",
-                        "comments", _("This program assists in the prevention and recovery"
-                                      " of Repetitive Strain Injury (RSI)."),
-                        "translator-credits", workrave_translators,
-                        "authors", workrave_authors,
-                        "logo", pixbuf,
+                        "copyright",
+                        workrave_copyright,
+                        "website",
+                        "http://www.workrave.org",
+                        "website_label",
+                        "www.workrave.org",
+                        "comments",
+                        _("This program assists in the prevention and recovery"
+                          " of Repetitive Strain Injury (RSI)."),
+                        "translator-credits",
+                        workrave_translators,
+                        "authors",
+                        workrave_authors,
+                        "logo",
+                        pixbuf,
                         NULL);
   g_object_unref(pixbuf);
 }
@@ -243,7 +250,7 @@ on_menu_command(GSimpleAction *action, GVariant *parameter, gpointer user_data)
                         menu_data[index].autostart ? G_DBUS_CALL_FLAGS_NONE : G_DBUS_CALL_FLAGS_NO_AUTO_START,
                         -1,
                         NULL,
-                        (GAsyncReadyCallback) dbus_call_finish,
+                        (GAsyncReadyCallback)dbus_call_finish,
                         applet);
     }
 }
@@ -251,7 +258,7 @@ on_menu_command(GSimpleAction *action, GVariant *parameter, gpointer user_data)
 static void
 on_menu_mode(GSimpleAction *action, GVariant *parameter, gpointer user_data)
 {
-  g_action_change_state (G_ACTION(action), parameter);
+  g_action_change_state(G_ACTION(action), parameter);
 }
 
 static void
@@ -259,7 +266,7 @@ on_menu_toggle(GSimpleAction *action, GVariant *parameter, gpointer user_data)
 {
   GVariant *state = g_action_get_state(G_ACTION(action));
   gboolean new_state = !g_variant_get_boolean(state);
-  g_action_change_state (G_ACTION(action), g_variant_new_boolean(new_state));
+  g_action_change_state(G_ACTION(action), g_variant_new_boolean(new_state));
   g_variant_unref(state);
 }
 
@@ -276,7 +283,7 @@ on_menu_toggle_changed(GSimpleAction *action, GVariant *value, gpointer user_dat
     }
 
   g_simple_action_set_state(action, value);
-  
+
   GDBusProxy *proxy = workrave_timerbox_control_get_control_proxy(applet->priv->timerbox_control);
   if (proxy != NULL)
     {
@@ -286,7 +293,7 @@ on_menu_toggle_changed(GSimpleAction *action, GVariant *value, gpointer user_dat
                         G_DBUS_CALL_FLAGS_NO_AUTO_START,
                         -1,
                         NULL,
-                        (GAsyncReadyCallback) dbus_call_finish,
+                        (GAsyncReadyCallback)dbus_call_finish,
                         &applet);
     }
 }
@@ -308,25 +315,25 @@ on_menu_mode_changed(GSimpleAction *action, GVariant *value, gpointer user_data)
                         G_DBUS_CALL_FLAGS_NO_AUTO_START,
                         -1,
                         NULL,
-                        (GAsyncReadyCallback) dbus_call_finish,
+                        (GAsyncReadyCallback)dbus_call_finish,
                         &applet);
     }
 }
 
-static const GActionEntry menu_actions [] = {
-  { "open",        on_menu_command    },
-  { "statistics",  on_menu_command    },
-  { "preferences", on_menu_command    },
-  { "exercises",   on_menu_command    },
-  { "restbreak",   on_menu_command    },
-  { "mode",        on_menu_mode,   "s", "'normal'", on_menu_mode_changed },
-  { "join",        on_menu_command    },
-  { "disconnect",  on_menu_command    },
-  { "reconnect",   on_menu_command    },
-  { "showlog",     on_menu_toggle, NULL, "false", on_menu_toggle_changed },
-  { "readingmode", on_menu_toggle, NULL, "false", on_menu_toggle_changed },
-  { "about",       on_menu_about      },
-  { "quit",        on_menu_command    },
+static const GActionEntry menu_actions[] = {
+  {"open", on_menu_command},
+  {"statistics", on_menu_command},
+  {"preferences", on_menu_command},
+  {"exercises", on_menu_command},
+  {"restbreak", on_menu_command},
+  {"mode", on_menu_mode, "s", "'normal'", on_menu_mode_changed},
+  {"join", on_menu_command},
+  {"disconnect", on_menu_command},
+  {"reconnect", on_menu_command},
+  {"showlog", on_menu_toggle, NULL, "false", on_menu_toggle_changed},
+  {"readingmode", on_menu_toggle, NULL, "false", on_menu_toggle_changed},
+  {"about", on_menu_about},
+  {"quit", on_menu_command},
 };
 
 static gboolean
@@ -338,13 +345,14 @@ button_pressed(GtkWidget *widget, GdkEventButton *event, WorkraveApplet *applet)
     {
       GDBusProxy *proxy = workrave_timerbox_control_get_applet_proxy(applet->priv->timerbox_control);
       if (proxy != NULL)
-        {          g_dbus_proxy_call(proxy,
+        {
+          g_dbus_proxy_call(proxy,
                             "ButtonClicked",
                             g_variant_new("(u)", event->button),
                             G_DBUS_CALL_FLAGS_NO_AUTO_START,
                             -1,
                             NULL,
-                            (GAsyncReadyCallback) dbus_call_finish,
+                            (GAsyncReadyCallback)dbus_call_finish,
                             &applet);
           ret = TRUE;
         }
@@ -353,7 +361,6 @@ button_pressed(GtkWidget *widget, GdkEventButton *event, WorkraveApplet *applet)
   return ret;
 }
 
-
 static void
 workrave_applet_class_init(WorkraveAppletClass *class)
 {
@@ -364,31 +371,27 @@ workrave_applet_fill(WorkraveApplet *applet)
 {
   applet->priv->timerbox_control = g_object_new(WORKRAVE_TIMERBOX_CONTROL_TYPE, NULL);
   applet->priv->image = workrave_timerbox_control_get_image(applet->priv->timerbox_control);
-  g_signal_connect(G_OBJECT(applet->priv->timerbox_control), "menu-changed", G_CALLBACK(on_menu_changed),  applet);
-  g_signal_connect(G_OBJECT(applet->priv->timerbox_control), "alive-changed", G_CALLBACK(on_alive_changed),  applet);
+  g_signal_connect(G_OBJECT(applet->priv->timerbox_control), "menu-changed", G_CALLBACK(on_menu_changed), applet);
+  g_signal_connect(G_OBJECT(applet->priv->timerbox_control), "alive-changed", G_CALLBACK(on_alive_changed), applet);
 
   workrave_timerbox_control_set_tray_icon_visible_when_not_running(applet->priv->timerbox_control, TRUE);
-  workrave_timerbox_control_set_tray_icon_mode(applet->priv->timerbox_control, WORKRAVE_TIMERBOX_CONTROL_TRAY_ICON_MODE_ALWAYS);
-  
+  workrave_timerbox_control_set_tray_icon_mode(applet->priv->timerbox_control, WORKRAVE_TIMERBOX_CONTROL_TRAY_ICON_MODE_FOLLOW);
+
   applet->priv->action_group = g_simple_action_group_new();
-  g_action_map_add_action_entries (G_ACTION_MAP (applet->priv->action_group),
-                                   menu_actions,
-                                   G_N_ELEMENTS (menu_actions),
-                                   applet);
+  g_action_map_add_action_entries(G_ACTION_MAP(applet->priv->action_group), menu_actions, G_N_ELEMENTS(menu_actions), applet);
 
   gchar *ui_path = g_build_filename(WORKRAVE_UIDATADIR, "workrave-gnome-applet-menu.xml", NULL);
   panel_applet_setup_menu_from_file(PANEL_APPLET(applet), ui_path, applet->priv->action_group, GETTEXT_PACKAGE);
   g_free(ui_path);
 
-  gtk_widget_insert_action_group (GTK_WIDGET (applet), "workrave",
-                                  G_ACTION_GROUP (applet->priv->action_group));
+  gtk_widget_insert_action_group(GTK_WIDGET(applet), "workrave", G_ACTION_GROUP(applet->priv->action_group));
 
   panel_applet_set_flags(PANEL_APPLET(applet), PANEL_APPLET_EXPAND_MINOR);
 
   gtk_container_set_border_width(GTK_CONTAINER(applet), 0);
 
   gtk_widget_set_events(GTK_WIDGET(applet), gtk_widget_get_events(GTK_WIDGET(applet)) | GDK_BUTTON_PRESS_MASK);
-  g_signal_connect(G_OBJECT(applet), "button_press_event", G_CALLBACK(button_pressed),  applet);
+  g_signal_connect(G_OBJECT(applet), "button_press_event", G_CALLBACK(button_pressed), applet);
 
   gtk_container_add(GTK_CONTAINER(applet), GTK_WIDGET(applet->priv->image));
 
@@ -411,7 +414,6 @@ workrave_applet_init(WorkraveApplet *applet)
   workrave_applet_fill(applet);
 }
 
-
 static gboolean
 applet_factory(PanelApplet *applet, const gchar *iid, gpointer user_data)
 {
@@ -424,7 +426,4 @@ applet_factory(PanelApplet *applet, const gchar *iid, gpointer user_data)
   return FALSE;
 }
 
-PANEL_APPLET_IN_PROCESS_FACTORY("WorkraveAppletFactory",
-                                WORKRAVE_TYPE_APPLET,
-                                applet_factory,
-                                NULL)
+PANEL_APPLET_IN_PROCESS_FACTORY("WorkraveAppletFactory", WORKRAVE_TYPE_APPLET, applet_factory, NULL)
