@@ -16,11 +16,11 @@
 //
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#  include "config.h"
 #endif
 
 #include <gdk/gdk.h>
-#include <libxfce4panel/xfce-panel-plugin.h>
+#include <libxfce4panel/libxfce4panel.h>
 
 #include <gio/gio.h>
 
@@ -32,7 +32,7 @@
 
 typedef struct _WorkraveApplet
 {
-  XfcePanelPlugin* plugin;
+  XfcePanelPlugin *plugin;
 
   WorkraveTimerboxControl *timerbox_control;
   GtkImage *image;
@@ -56,32 +56,28 @@ struct Menuitems
   char *dbuscmd;
 };
 
-// TODO: move this meta data to GenericDbusApplet
-static struct Menuitems menu_data[] =
-  {
-    { MENU_COMMAND_OPEN,                  TRUE,  "OpenMain"          },
-    { MENU_COMMAND_PREFERENCES,           FALSE, "Preferences"       },
-    { MENU_COMMAND_EXERCISES,             FALSE, "Exercises"         },
-    { MENU_COMMAND_REST_BREAK,            FALSE, "RestBreak"         },
-    { MENU_COMMAND_MODE_SUBMENU,          FALSE, NULL                },
-    { MENU_COMMAND_MODE_NORMAL,           FALSE, NULL                },
-    { MENU_COMMAND_MODE_QUIET,            FALSE, NULL                },
-    { MENU_COMMAND_MODE_SUSPENDED,        FALSE, NULL                },
-    { MENU_COMMAND_NETWORK_SUBMENU,       FALSE, NULL                },
-    { MENU_COMMAND_NETWORK_CONNECT,       FALSE, "NetworkConnect"    },
-    { MENU_COMMAND_NETWORK_DISCONNECT,    FALSE, "NetworkDisconnect" },
-    { MENU_COMMAND_NETWORK_LOG,           FALSE, "NetworkLog"        },
-    { MENU_COMMAND_NETWORK_RECONNECT,     FALSE, "NetworkReconnect"  },
-    { MENU_COMMAND_STATISTICS,            FALSE, "Statistics"        },
-    { MENU_COMMAND_ABOUT,                 FALSE, NULL                },
-    { MENU_COMMAND_MODE_READING,          FALSE, "ReadingMode"       },
-    { MENU_COMMAND_QUIT,                  FALSE, "Quit"              }
-  };
+static struct Menuitems menu_data[] = {{MENU_COMMAND_OPEN, TRUE, "OpenMain"},
+                                       {MENU_COMMAND_PREFERENCES, FALSE, "Preferences"},
+                                       {MENU_COMMAND_EXERCISES, FALSE, "Exercises"},
+                                       {MENU_COMMAND_REST_BREAK, FALSE, "RestBreak"},
+                                       {MENU_COMMAND_MODE_SUBMENU, FALSE, NULL},
+                                       {MENU_COMMAND_MODE_NORMAL, FALSE, NULL},
+                                       {MENU_COMMAND_MODE_QUIET, FALSE, NULL},
+                                       {MENU_COMMAND_MODE_SUSPENDED, FALSE, NULL},
+                                       {MENU_COMMAND_NETWORK_SUBMENU, FALSE, NULL},
+                                       {MENU_COMMAND_NETWORK_CONNECT, FALSE, "NetworkConnect"},
+                                       {MENU_COMMAND_NETWORK_DISCONNECT, FALSE, "NetworkDisconnect"},
+                                       {MENU_COMMAND_NETWORK_LOG, FALSE, "NetworkLog"},
+                                       {MENU_COMMAND_NETWORK_RECONNECT, FALSE, "NetworkReconnect"},
+                                       {MENU_COMMAND_STATISTICS, FALSE, "Statistics"},
+                                       {MENU_COMMAND_ABOUT, FALSE, NULL},
+                                       {MENU_COMMAND_MODE_READING, FALSE, "ReadingMode"},
+                                       {MENU_COMMAND_QUIT, FALSE, "Quit"}};
 
 int
 lookup_menu_index_by_id(enum MenuCommand id)
 {
-  for (int i = 0; i < sizeof(menu_data)/sizeof(struct Menuitems); i++)
+  for (int i = 0; i < sizeof(menu_data) / sizeof(struct Menuitems); i++)
     {
       if (menu_data[i].id == id)
         {
@@ -106,15 +102,15 @@ lookup_menu_index_by_menu_item(WorkraveApplet *applet, GtkMenuItem *item)
   return -1;
 }
 
-
-void on_alive_changed(gpointer instance, gboolean alive, gpointer user_data)
+void
+on_alive_changed(gpointer instance, gboolean alive, gpointer user_data)
 {
-  WorkraveApplet *applet = (WorkraveApplet*)user_data;
+  WorkraveApplet *applet = (WorkraveApplet *)user_data;
   applet->alive = alive;
 
   if (!alive)
     {
-      for (int i = 0; i < sizeof(menu_data)/sizeof(struct Menuitems); i++)
+      for (int i = 0; i < sizeof(menu_data) / sizeof(struct Menuitems); i++)
         {
           GtkMenuItem *item = applet->menu_items[i];
           if (item != NULL)
@@ -125,12 +121,13 @@ void on_alive_changed(gpointer instance, gboolean alive, gpointer user_data)
     }
 }
 
-void on_menu_changed(gpointer instance, GVariant *parameters, gpointer user_data)
+void
+on_menu_changed(gpointer instance, GVariant *parameters, gpointer user_data)
 {
-  WorkraveApplet *applet = (WorkraveApplet*)user_data;
+  WorkraveApplet *applet = (WorkraveApplet *)user_data;
 
   GVariantIter *iter;
-  g_variant_get (parameters, "(a(sii))", &iter);
+  g_variant_get(parameters, "(a(sii))", &iter);
 
   char *text;
   int id;
@@ -207,10 +204,9 @@ void on_menu_changed(gpointer instance, GVariant *parameters, gpointer user_data
         }
     }
 
-  g_variant_iter_free (iter);
+  g_variant_iter_free(iter);
 }
 
-
 static void
 dbus_call_finish(GDBusProxy *proxy, GAsyncResult *res, gpointer user_data)
 {
@@ -233,7 +229,7 @@ dbus_call_finish(GDBusProxy *proxy, GAsyncResult *res, gpointer user_data)
 static void
 on_menu_command(GtkMenuItem *item, gpointer user_data)
 {
-  WorkraveApplet *applet = (WorkraveApplet*)user_data;
+  WorkraveApplet *applet = (WorkraveApplet *)user_data;
 
   if (applet->inhibit > 0)
     {
@@ -246,7 +242,7 @@ on_menu_command(GtkMenuItem *item, gpointer user_data)
       return;
     }
 
-  switch(menu_data[index].id)
+  switch (menu_data[index].id)
     {
     case MENU_COMMAND_ABOUT:
       on_menu_about(item, applet);
@@ -263,7 +259,7 @@ on_menu_command(GtkMenuItem *item, gpointer user_data)
                               menu_data[index].autostart ? G_DBUS_CALL_FLAGS_NONE : G_DBUS_CALL_FLAGS_NO_AUTO_START,
                               -1,
                               NULL,
-                              (GAsyncReadyCallback) dbus_call_finish,
+                              (GAsyncReadyCallback)dbus_call_finish,
                               applet);
           }
       }
@@ -280,21 +276,32 @@ on_menu_about(GtkMenuItem *item, WorkraveApplet *applet)
   gtk_container_set_border_width(GTK_CONTAINER(about), 5);
 
   gtk_show_about_dialog(NULL,
-                        "name", "Workrave",
-                        "program-name", "Workrave",
+                        "name",
+                        "Workrave",
+                        "program-name",
+                        "Workrave",
 #ifdef GIT_VERSION
-                        "version", PACKAGE_VERSION "\n(" GIT_VERSION ")",
+                        "version",
+                        PACKAGE_VERSION "\n(" GIT_VERSION ")",
 #else
-                        "version", PACKAGE_VERSION,
+                        "version",
+                        PACKAGE_VERSION,
 #endif
-                        "copyright", workrave_copyright,
-                        "website", "http://www.workrave.org",
-                        "website_label", "www.workrave.org",
-                        "comments", _("This program assists in the prevention and recovery"
-                                      " of Repetitive Strain Injury (RSI)."),
-                        "translator-credits", workrave_translators,
-                        "authors", workrave_authors,
-                        "logo", pixbuf,
+                        "copyright",
+                        workrave_copyright,
+                        "website",
+                        "http://www.workrave.org",
+                        "website_label",
+                        "www.workrave.org",
+                        "comments",
+                        _("This program assists in the prevention and recovery"
+                          " of Repetitive Strain Injury (RSI)."),
+                        "translator-credits",
+                        workrave_translators,
+                        "authors",
+                        workrave_authors,
+                        "logo",
+                        pixbuf,
                         NULL);
   g_object_unref(pixbuf);
 }
@@ -302,7 +309,7 @@ on_menu_about(GtkMenuItem *item, WorkraveApplet *applet)
 static void
 on_menu_check_changed(GtkMenuItem *item, gpointer user_data)
 {
-  WorkraveApplet *applet = (WorkraveApplet*)user_data;
+  WorkraveApplet *applet = (WorkraveApplet *)user_data;
 
   if (applet->inhibit > 0)
     {
@@ -330,7 +337,7 @@ on_menu_check_changed(GtkMenuItem *item, gpointer user_data)
                         G_DBUS_CALL_FLAGS_NO_AUTO_START,
                         -1,
                         NULL,
-                        (GAsyncReadyCallback) dbus_call_finish,
+                        (GAsyncReadyCallback)dbus_call_finish,
                         applet);
     }
 }
@@ -338,20 +345,20 @@ on_menu_check_changed(GtkMenuItem *item, gpointer user_data)
 static void
 on_menu_radio_changed(GtkMenuItem *item, gpointer user_data)
 {
-  WorkraveApplet *applet = (WorkraveApplet*)user_data;
+  WorkraveApplet *applet = (WorkraveApplet *)user_data;
 
   if (applet->inhibit > 0)
     {
       return;
     }
 
-  int index = lookup_menu_index_by_menu_item(applet,item);
+  int index = lookup_menu_index_by_menu_item(applet, item);
   if (index == -1)
     {
       return;
     }
 
-  switch(menu_data[index].id)
+  switch (menu_data[index].id)
     {
     case MENU_COMMAND_MODE_NORMAL:
       on_menu_mode_changed("normal", applet);
@@ -379,35 +386,37 @@ on_menu_mode_changed(const char *mode, WorkraveApplet *applet)
                         G_DBUS_CALL_FLAGS_NO_AUTO_START,
                         -1,
                         NULL,
-                        (GAsyncReadyCallback) dbus_call_finish,
+                        (GAsyncReadyCallback)dbus_call_finish,
                         &applet);
     }
 }
 
-static void workrave_applet_fill(WorkraveApplet *applet)
+static void
+workrave_applet_fill(WorkraveApplet *applet)
 {
   applet->timerbox_control = g_object_new(WORKRAVE_TIMERBOX_CONTROL_TYPE, NULL);
   applet->image = workrave_timerbox_control_get_image(applet->timerbox_control);
-  g_signal_connect(G_OBJECT(applet->timerbox_control), "menu-changed", G_CALLBACK(on_menu_changed),  applet);
-  g_signal_connect(G_OBJECT(applet->timerbox_control), "alive-changed", G_CALLBACK(on_alive_changed),  applet);
+  g_signal_connect(G_OBJECT(applet->timerbox_control), "menu-changed", G_CALLBACK(on_menu_changed), applet);
+  g_signal_connect(G_OBJECT(applet->timerbox_control), "alive-changed", G_CALLBACK(on_alive_changed), applet);
 
   workrave_timerbox_control_set_tray_icon_visible_when_not_running(applet->timerbox_control, TRUE);
-  workrave_timerbox_control_set_tray_icon_mode(applet->timerbox_control, WORKRAVE_TIMERBOX_CONTROL_TRAY_ICON_MODE_ALWAYS);
+  workrave_timerbox_control_set_tray_icon_mode(applet->timerbox_control, WORKRAVE_TIMERBOX_CONTROL_TRAY_ICON_MODE_FOLLOW);
 
   gtk_container_add(GTK_CONTAINER(applet->plugin), GTK_WIDGET(applet->image));
   gtk_widget_show_all(GTK_WIDGET(applet->plugin));
 }
 
-static void workrave_applet_construct(XfcePanelPlugin *plugin)
+static void
+workrave_applet_construct(XfcePanelPlugin *plugin)
 {
-  WorkraveApplet *applet = panel_slice_new0(WorkraveApplet);
+  WorkraveApplet *applet = g_slice_new0(WorkraveApplet);
   applet->plugin = plugin;
   applet->image = NULL;
   applet->timerbox_control = NULL;
   applet->alive = FALSE;
   applet->inhibit = 0;
 
-  for (int i = 0; i < MENU_COMMAND_SIZEOF;i ++)
+  for (int i = 0; i < MENU_COMMAND_SIZEOF; i++)
     {
       applet->menu_items[i] = NULL;
     }
