@@ -20,14 +20,13 @@
 #include "preinclude.h"
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#  include "config.h"
 #endif
 
 #include "debug.hh"
 
 #include "EventImage.hh"
 
-
 void
 EventImage::on_realize()
 {
@@ -51,25 +50,19 @@ EventImage::on_realize()
 
   attributes.wclass = GDK_INPUT_ONLY;
   attributes.event_mask = gtk_widget_get_events(widget);
-  attributes.event_mask |= (GDK_EXPOSURE_MASK |
-                            GDK_BUTTON_MOTION_MASK |
-                            GDK_BUTTON_PRESS_MASK |
-                            GDK_BUTTON_RELEASE_MASK |
-                            GDK_ENTER_NOTIFY_MASK |
-                            GDK_LEAVE_NOTIFY_MASK);
+  attributes.event_mask |= (GDK_EXPOSURE_MASK | GDK_BUTTON_MOTION_MASK | GDK_BUTTON_PRESS_MASK | GDK_BUTTON_RELEASE_MASK
+                            | GDK_ENTER_NOTIFY_MASK | GDK_LEAVE_NOTIFY_MASK);
 
   gint attributes_mask = GDK_WA_X | GDK_WA_Y;
 
   Gtk::Image::on_realize();
 
-  event_window = gdk_window_new(gtk_widget_get_parent_window(widget),
-                                &attributes, attributes_mask);
+  event_window = gdk_window_new(gtk_widget_get_parent_window(widget), &attributes, attributes_mask);
 
   gdk_window_set_user_data(event_window, widget);
   gdk_window_show(event_window);
 }
 
-
 void
 EventImage::on_unrealize()
 {
@@ -83,7 +76,6 @@ EventImage::on_unrealize()
   Gtk::Image::on_unrealize();
 }
 
-
 bool
 EventImage::on_map_event(GdkEventAny *event)
 {
@@ -97,7 +89,6 @@ EventImage::on_map_event(GdkEventAny *event)
   return ret;
 }
 
-
 bool
 EventImage::on_unmap_event(GdkEventAny *event)
 {
@@ -117,15 +108,11 @@ EventImage::on_size_allocate(Gtk::Allocation &allocation)
   GtkWidget *widget = GTK_WIDGET(gobj());
 
 #ifdef HAVE_GTK3
-  if (gtk_widget_get_realized (widget))
-#else  // needed for 2.16
+  if (gtk_widget_get_realized(widget))
+#else // needed for 2.16
   if (GTK_WIDGET_REALIZED(widget))
 #endif
     {
-      gdk_window_move_resize(event_window,
-                             allocation.get_x(),
-                             allocation.get_y() ,
-                             allocation.get_width(),
-                             allocation.get_height());
+      gdk_window_move_resize(event_window, allocation.get_x(), allocation.get_y(), allocation.get_width(), allocation.get_height());
     }
 }
